summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
authorMichael Stahl <mstahl@redhat.com>2014-02-20 11:51:43 +0100
committerMichael Stahl <mstahl@redhat.com>2014-02-20 12:52:07 +0100
commit474b2ff232591442fb22363c82abc66e7e2101a0 (patch)
treecb157313acfd67551125a1366e33bd5847548baf /svx
parent55112988e67d627dc807fd30478c1c3f952c75f2 (diff)
svx: these Style members are floats
Change-Id: Id1a5e363c8c39b3ad9e61f9b914461d15f5c3028
Diffstat (limited to 'svx')
-rw-r--r--svx/source/dialog/framelink.cxx32
1 files changed, 16 insertions, 16 deletions
diff --git a/svx/source/dialog/framelink.cxx b/svx/source/dialog/framelink.cxx
index 82683743302c..b220a08be12b 100644
--- a/svx/source/dialog/framelink.cxx
+++ b/svx/source/dialog/framelink.cxx
@@ -1176,16 +1176,16 @@ void Style::Clear()
void Style::Set( double nP, double nD, double nS )
{
- /* nP nD nS -> mnPrim mnDist mnSecn
+ /* nP nD nS -> mfPrim mfDist mfSecn
--------------------------------------
any any 0 nP 0 0
0 any >0 nS 0 0
>0 0 >0 nP 0 0
>0 >0 >0 nP nD nS
*/
- mnPrim = rtl::math::round(nP ? nP : nS, 2);
- mnDist = rtl::math::round((nP && nS) ? nD : 0, 2);
- mnSecn = rtl::math::round((nP && nD) ? nS : 0, 2);
+ mfPrim = rtl::math::round(nP ? nP : nS, 2);
+ mfDist = rtl::math::round((nP && nS) ? nD : 0, 2);
+ mfSecn = rtl::math::round((nP && nD) ? nS : 0, 2);
}
void Style::Set( const Color& rColorPrim, const Color& rColorSecn, const Color& rColorGap, bool bUseGapColor, double nP, double nD, double nS )
@@ -1219,29 +1219,29 @@ void Style::Set( const SvxBorderLine& rBorder, double fScale, sal_uInt16 nMaxWid
// Enlarge the style if distance is too small due to rounding losses.
double nPixWidth = SCALEVALUE( nPrim + nDist + nSecn );
if( nPixWidth > GetWidth() )
- mnDist = nPixWidth - mnPrim - mnSecn;
+ mfDist = nPixWidth - mfPrim - mfSecn;
// Shrink the style if it is too thick for the control.
while( GetWidth() > nMaxWidth )
{
// First decrease space between lines.
- if( mnDist )
- --mnDist;
+ if (mfDist)
+ --mfDist;
// Still too thick? Decrease the line widths.
if( GetWidth() > nMaxWidth )
{
- if( rtl::math::approxEqual(mnPrim, 0.0) && rtl::math::approxEqual(mnPrim, mnSecn) )
+ if (rtl::math::approxEqual(mfPrim, 0.0) && rtl::math::approxEqual(mfPrim, mfSecn))
{
// Both lines equal - decrease both to keep symmetry.
- --mnPrim;
- --mnSecn;
+ --mfPrim;
+ --mfSecn;
}
else
{
// Decrease each line for itself
- if( mnPrim )
- --mnPrim;
- if( (GetWidth() > nMaxWidth) && !rtl::math::approxEqual(mnSecn, 0.0) )
- --mnSecn;
+ if (mfPrim)
+ --mfPrim;
+ if ((GetWidth() > nMaxWidth) && !rtl::math::approxEqual(mfSecn, 0.0))
+ --mfSecn;
}
}
}
@@ -1261,8 +1261,8 @@ void Style::Set( const SvxBorderLine* pBorder, double fScale, sal_uInt16 nMaxWid
Style& Style::MirrorSelf()
{
- if( mnSecn )
- std::swap( mnPrim, mnSecn );
+ if (mfSecn)
+ std::swap( mfPrim, mfSecn );
if( meRefMode != REFMODE_CENTERED )
meRefMode = (meRefMode == REFMODE_BEGIN) ? REFMODE_END : REFMODE_BEGIN;
return *this;